@@ -13,6 +13,7 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
     m3 <- insight::download_model("brms_2")
     m4 <- insight::download_model("brms_zi_3")
     m5 <- insight::download_model("brms_mv_5")
+    m6 <- insight::download_model("brms_corr_re1")
 
     # Tests -------------------------------------------------------------------
 
@@ -171,6 +172,14 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
           random = "patient"
         )
       )
+      expect_identical(
+        find_variables(m6),
+        list(
+          response = "y",
+          conditional = "x",
+          random = "id"
+        )
+      )
       expect_identical(
         find_variables(m1, effects = "fixed"),
         list(
@@ -243,6 +252,7 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
         )
       ))
       expect_equal(find_random(m5, flatten = TRUE), "persons")
+      expect_equal(find_random(m6, flatten = TRUE), "id")
     })
 
 
@@ -252,6 +262,13 @@ if (.runThisTest || Sys.getenv("USER") == "travis") {
     })
 
 
+    test_that("get_data", {
+      d <- get_data(m6)
+      expect_equal(nrow(d), 200)
+      expect_equal(ncol(d), 3)
+    })
+
+
     test_that("find_paramaters", {
       expect_equal(
         find_parameters(m1),
