@@ -89,7 +89,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 7)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c(
         "1|2",
         "2|3",
