@@ -98,7 +98,7 @@ if (require("testthat") &&
     expect_equal(nrow(get_parameters(m1)), 8)
     expect_equal(nrow(get_parameters(m1, component = "zi")), 3)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c(
         "count_(Intercept)",
         "count_femWomen",
